@@ -32,7 +32,11 @@ L<Badger::Utils|Badger::Utils>.
 
 =head1 SEE ALSO
 
-L<XAS|XAS>
+=over 4
+
+=item L<XAS|XAS>
+
+=back
 
 =head1 AUTHOR
 
